@@ -8,6 +8,10 @@ if(l1==l2) stop("The two competing models have identical log-likelihoods!")
 p1 <- obj1$t.edf
 p2 <- obj2$t.edf
 n  <- obj1$n
+n1 <- obj2$n
+
+if(n != n1) stop("The two competing models have different sample sizes.")
+
 li12 <- obj1$fit$l.par - obj2$fit$l.par
 w  <- sqrt(var(li12)*(n-1))
 vt <- (l1-l2-(p1-p2)/2*log(n))/w  
